
# q-expansion of newform 1014.2.g.b, downloaded from the LMFDB on 06 June 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 1014
weight = 2
poly_data = [729, 0, 0, -324, 0, 0, 72, 0, 0, -12, 0, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-81, 0, 0, 18, 0, 0, -3, 0, 0, 1, 0, 0], 81], [[0, -81, 0, 0, 18, 0, 0, -3, 0, 0, 1, 0], 81], [[0, 0, 162, 0, 0, -45, 0, 0, 3, 0, 0, -1], 243], [[0, 0, 324, 0, 0, -72, 0, 0, 12, 0, 0, -1], 243], [[243, 0, 0, -63, 0, 0, 15, 0, 0, -2, 0, 0], 81], [[0, 243, 0, 0, -63, 0, 0, 15, 0, 0, -2, 0], 81], [[-324, 0, 0, 90, 0, 0, -15, 0, 0, 2, 0, 0], 81], [[0, -324, 0, 0, 90, 0, 0, -15, 0, 0, 2, 0], 81], [[0, 0, 135, 0, 0, -27, 0, 0, 6, 0, 0, -1], 81], [[0, 0, -486, 0, 0, 153, 0, 0, -30, 0, 0, 4], 243]]

hecke_ring_character_values = [[677, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [847, [0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0], [0, 0, 0, 0, 0, 1, 0, 0, 0, -1, 0, 0], [1, 1, 0, 0, 0, 0, 0, 0, -1, 0, 0, -1], [0, 0, 0, -1, 1, 0, 0, 1, 0, 0, -1, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 1, 0, -1, 0, 1, 0, 0, 0, -1, -1, 1], [1, 0, 0, 1, -1, 0, 0, 1, 1, 0, -1, 0], [0, -1, 0, 0, 0, -1, 0, 0, 0, 1, 0, -1], [0, 1, 0, 0, 0, -1, 0, 0, 0, 1, 0, 1], [-1, 0, 0, -1, 1, 2, 0, -1, -1, 2, 1, 0], [-1, 1, 0, 1, 1, 0, 0, -1, 1, 0, -1, -1], [0, 0, 0, 0, 0, -2, -6, 0, 0, 2, 0, 0], [0, -2, 0, 1, 0, 2, 0, 0, 0, 2, -1, 2], [0, -1, 6, 1, -1, 0, 0, -1, 0, 0, 1, -1], [0, -1, 6, 0, 2, 1, -6, 2, 0, -1, 0, -1], [0, -2, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2], [0, 2, 0, 0, 0, 2, 0, 0, 0, 2, 0, -2], [1, 0, 0, 0, 0, -2, 0, 0, 1, -2, 0, 0], [0, 0, 0, -1, -1, -1, 6, -1, 0, 1, -1, 0], [1, 0, 0, -1, -1, 0, 0, 1, -1, 0, 1, 0], [6, 1, 0, 0, 2, 1, 0, -2, 0, 1, 0, -1], [0, 0, 0, 3, 3, 2, 0, 3, 0, -2, 3, 0], [0, 0, 6, 2, -2, 0, 0, -2, 0, 0, 2, 0], [5, 0, 0, -2, 2, 0, 0, -2, 5, 0, 2, 0], [0, 0, 6, 4, 0, 0, 6, 0, 0, 0, 4, 0], [0, -1, 0, -2, 0, 1, 0, 0, -6, 1, 2, 1], [0, 0, 0, 0, 2, 0, 0, 2, 0, 0, 0, 0], [-5, 0, 0, -1, 1, -1, 0, -1, -5, -1, 1, 0], [0, 2, -6, 0, -2, -2, 6, -2, 0, 2, 0, 2], [0, -1, 0, -4, 0, 1, 0, 0, -4, 1, 4, 1], [0, 2, 6, 0, -1, -2, -6, -1, 0, 2, 0, 2], [0, 2, 6, -3, 3, 0, 0, 3, 0, 0, -3, 2], [2, -2, 0, 0, 1, -2, 0, -1, 0, -2, 0, 2], [0, 0, 0, 2, 2, 0, 6, 2, 0, 0, 2, 0], [5, 1, 0, -2, -2, 0, 0, 2, -5, 0, 2, -1], [-2, -2, 0, 0, 4, -2, 0, -4, 0, -2, 0, 2], [-1, -4, 0, -4, -4, 0, 0, 4, 1, 0, 4, 4], [0, 2, 0, -2, 2, 0, 0, 2, 0, 0, -2, 2], [0, -1, 0, -6, 0, -1, 0, 0, 0, 1, -6, -1], [0, 2, 6, 1, 0, 2, 6, 0, 0, -2, 1, 2], [0, -1, 0, -2, 0, 1, 0, 0, 0, 1, 2, 1], [0, 3, 0, 0, 2, -3, 0, 2, 0, 3, 0, 3], [1, 2, 0, 0, 0, 0, 0, 0, -1, 0, 0, -2], [0, 0, 0, -2, -2, 1, 0, -2, 0, -1, -2, 0], [0, 3, 0, -6, 0, -3, 0, 0, 8, -3, 6, -3], [12, 0, 0, 0, 1, 0, 0, -1, 0, 0, 0, 0], [1, 0, 0, 0, 0, 3, 0, 0, 1, 3, 0, 0], [0, 0, 0, -4, -4, 0, 0, -4, 0, 0, -4, 0], [-5, -1, 0, 1, 1, 0, 0, -1, 5, 0, -1, 1], [0, -1, 6, -1, 0, -1, 6, 0, 0, 1, -1, -1], [0, 0, 0, -1, -1, -5, 6, -1, 0, 5, -1, 0], [-1, -4, 0, 5, 5, 0, 0, -5, 1, 0, -5, 4], [0, -4, -6, 2, 0, -4, -6, 0, 0, 4, 2, -4], [0, 3, -6, -7, 0, 3, -6, 0, 0, -3, -7, 3], [0, -4, 0, 0, 0, 4, 0, 0, 0, -4, 0, -4], [0, 2, 6, 0, 0, -2, -6, 0, 0, 2, 0, 2], [-1, -3, 0, 4, 4, 0, 0, -4, 1, 0, -4, 3], [0, 2, 0, 8, 0, -2, 0, 0, 12, -2, -8, -2], [0, -4, 6, 0, 0, 0, 0, 0, 0, 0, 0, -4], [0, 2, 0, 2, 0, -2, 0, 0, -8, -2, -2, -2], [0, 3, -12, 0, 0, 0, 0, 0, 0, 0, 0, 3], [11, 0, 0, 3, 3, 0, 0, -3, -11, 0, -3, 0], [0, 2, -6, 2, 0, 2, -6, 0, 0, -2, 2, 2], [6, 1, 0, 0, 3, 1, 0, -3, 0, 1, 0, -1], [0, 0, 0, -2, -2, -4, -6, -2, 0, 4, -2, 0], [1, 0, 0, 0, 0, -4, 0, 0, 1, -4, 0, 0], [0, 1, 0, 7, 0, -1, 0, 0, 4, -1, -7, -1], [0, -4, -12, 0, -1, 4, 12, -1, 0, -4, 0, -4], [-11, -1, 0, -3, -3, 0, 0, 3, 11, 0, 3, 1], [0, 0, 0, -1, -1, 2, 6, -1, 0, -2, -1, 0], [0, -2, 0, -4, 4, 0, 0, 4, 0, 0, -4, -2], [16, -1, 0, 0, 2, -1, 0, -2, 0, -1, 0, 1], [12, -2, 0, 0, -4, -2, 0, 4, 0, -2, 0, 2], [5, 0, 0, -4, 4, 0, 0, -4, 5, 0, 4, 0], [0, 0, 0, 1, 1, 7, -6, 1, 0, -7, 1, 0], [0, 0, 0, -2, 0, 0, 0, 0, 0, 0, -2, 0], [-5, 6, 0, -3, -3, 0, 0, 3, 5, 0, 3, -6], [0, -2, -6, 5, -5, 0, 0, -5, 0, 0, 5, -2], [-5, 0, 0, -4, 4, -2, 0, -4, -5, -2, 4, 0], [0, 2, 6, 0, 7, -2, -6, 7, 0, 2, 0, 2], [7, 0, 0, 3, -3, 5, 0, 3, 7, 5, -3, 0], [0, 0, 0, 1, 1, -5, 18, 1, 0, 5, 1, 0], [0, -9, 0, -3, 0, 9, 0, 0, 16, 9, 3, 9], [0, 0, 0, 0, 0, 0, 0, 0, 18, 0, 0, 0], [0, -8, -6, 0, -3, 8, 6, -3, 0, -8, 0, -8], [0, -4, 6, -7, 7, 0, 0, 7, 0, 0, -7, -4], [-1, 0, 0, 1, -1, -8, 0, 1, -1, -8, -1, 0], [0, 0, 0, 6, 6, -9, 0, 6, 0, 9, 6, 0], [-1, -6, 0, -1, -1, 0, 0, 1, 1, 0, 1, 6], [0, -2, 18, 2, 0, -2, 18, 0, 0, 2, 2, -2], [0, 3, -6, 7, -7, 0, 0, -7, 0, 0, 7, 3], [-1, 0, 0, 3, -3, 2, 0, 3, -1, 2, -3, 0], [0, 0, -12, 7, 0, 0, -12, 0, 0, 0, 7, 0], [5, 0, 0, 1, -1, -2, 0, 1, 5, -2, -1, 0], [0, 2, 12, 0, -6, -2, -12, -6, 0, 2, 0, 2], [0, 0, 0, -4, -4, -4, -6, -4, 0, 4, -4, 0], [0, 3, -6, 0, 1, -3, 6, 1, 0, 3, 0, 3], [4, 2, 0, 0, -4, 2, 0, 4, 0, 2, 0, -2], [-5, 9, 0, -5, -5, 0, 0, 5, 5, 0, 5, -9], [26, 0, 0, 0, -3, 0, 0, 3, 0, 0, 0, 0], [0, 1, 0, -4, 4, 0, 0, 4, 0, 0, -4, 1], [0, 10, 6, -3, 0, 10, 6, 0, 0, -10, -3, 10], [0, -5, -6, -5, 0, -5, -6, 0, 0, 5, -5, -5], [0, 2, 0, -7, 0, -2, 0, 0, -10, -2, 7, -2], [-19, 0, 0, 3, -3, 4, 0, 3, -19, 4, -3, 0], [0, 0, 0, -1, -1, -2, 24, -1, 0, 2, -1, 0], [0, 8, -6, -1, 1, 0, 0, 1, 0, 0, -1, 8], [0, 2, -24, 0, -2, -2, 24, -2, 0, 2, 0, 2], [-18, -7, 0, 0, -1, -7, 0, 1, 0, -7, 0, 7], [4, 6, 0, 0, 6, 6, 0, -6, 0, 6, 0, -6], [5, 0, 0, 7, -7, 0, 0, 7, 5, 0, -7, 0], [0, 0, 0, -4, -4, -6, -18, -4, 0, 6, -4, 0], [13, 6, 0, -1, -1, 0, 0, 1, -13, 0, 1, -6], [7, -1, 0, 2, 2, 0, 0, -2, -7, 0, -2, 1], [0, -6, -12, 2, 0, -6, -12, 0, 0, 6, 2, -6], [1, 0, 0, 0, 0, 6, 0, 0, 1, 6, 0, 0], [0, 2, 0, -2, 0, 2, 0, 0, 0, -2, -2, 2], [0, 2, 6, 0, -12, -2, -6, -12, 0, 2, 0, 2], [0, 0, 18, 0, -6, 0, -18, -6, 0, 0, 0, 0], [5, -12, 0, 5, 5, 0, 0, -5, -5, 0, -5, 12], [0, 3, 0, -5, 0, -3, 0, 0, 30, -3, 5, -3], [0, 3, -6, 0, -6, -3, 6, -6, 0, 3, 0, 3], [0, -6, 12, 1, -1, 0, 0, -1, 0, 0, 1, -6], [-19, 0, 0, -1, 1, 2, 0, -1, -19, 2, 1, 0], [0, 1, 18, 2, 0, 1, 18, 0, 0, -1, 2, 1], [11, -6, 0, -1, -1, 0, 0, 1, -11, 0, 1, 6], [0, -5, -12, 2, 0, -5, -12, 0, 0, 5, 2, -5], [0, -1, 0, 2, 0, 1, 0, 0, -8, 1, -2, 1], [-7, 0, 0, -5, 5, 7, 0, -5, -7, 7, 5, 0], [1, -2, 0, 5, 5, 0, 0, -5, -1, 0, -5, 2], [0, 0, 0, -1, -1, 3, -6, -1, 0, -3, -1, 0], [0, -4, 0, -2, 0, 4, 0, 0, -6, 4, 2, 4], [-24, -3, 0, 0, -2, -3, 0, 2, 0, -3, 0, 3], [0, 0, -30, -4, 4, 0, 0, 4, 0, 0, -4, 0], [5, 0, 0, -9, 9, 2, 0, -9, 5, 2, 9, 0], [0, 0, 0, -6, -6, 11, 0, -6, 0, -11, -6, 0], [-13, 2, 0, -1, -1, 0, 0, 1, 13, 0, 1, -2], [0, -6, 12, -10, 0, -6, 12, 0, 0, 6, -10, -6], [0, -5, 6, 0, 11, 5, -6, 11, 0, -5, 0, -5], [-11, 0, 0, 1, -1, -14, 0, 1, -11, -14, -1, 0], [0, 0, 0, -2, -2, 5, 12, -2, 0, -5, -2, 0], [0, -2, 0, 12, 0, 2, 0, 0, -18, 2, -12, 2], [0, -2, 12, 6, -6, 0, 0, -6, 0, 0, 6, -2], [0, -5, 0, -2, 0, 5, 0, 0, -14, 5, 2, 5], [0, 10, 24, 0, 0, 0, 0, 0, 0, 0, 0, 10], [-13, -13, 0, -1, -1, 0, 0, 1, 13, 0, 1, 13], [0, 10, 6, -10, 0, 10, 6, 0, 0, -10, -10, 10], [-6, -8, 0, 0, 2, -8, 0, -2, 0, -8, 0, 8], [0, 0, 0, 1, 1, -19, -6, 1, 0, 19, 1, 0], [11, 0, 0, 5, -5, -9, 0, 5, 11, -9, -5, 0], [0, 1, 18, 5, 0, 1, 18, 0, 0, -1, 5, 1], [0, 0, 0, 9, 0, 0, 0, 0, -10, 0, -9, 0], [0, -2, 6, 0, 8, 2, -6, 8, 0, -2, 0, -2], [0, -4, 0, -1, 0, 4, 0, 0, 2, 4, 1, 4], [0, -1, 12, 0, 2, 1, -12, 2, 0, -1, 0, -1], [-30, -8, 0, 0, -2, -8, 0, 2, 0, -8, 0, 8], [0, 0, 0, 6, 6, 2, -6, 6, 0, -2, 6, 0], [-12, 2, 0, 0, 16, 2, 0, -16, 0, 2, 0, -2], [0, 0, 0, 4, 4, -3, 36, 4, 0, 3, 4, 0], [0, -12, 12, -1, 1, 0, 0, 1, 0, 0, -1, -12], [0, 7, -18, 5, 0, 7, -18, 0, 0, -7, 5, 7], [13, 0, 0, -10, 10, -11, 0, -10, 13, -11, 10, 0], [0, -6, 24, 0, 9, 6, -24, 9, 0, -6, 0, -6], [0, 0, 0, 7, 7, 4, -18, 7, 0, -4, 7, 0], [0, 11, 6, -5, 5, 0, 0, 5, 0, 0, -5, 11], [-4, 4, 0, 0, -14, 4, 0, 14, 0, 4, 0, -4], [10, 1, 0, 0, -14, 1, 0, 14, 0, 1, 0, -1], [-13, -4, 0, 3, 3, 0, 0, -3, 13, 0, -3, 4], [0, 9, 0, 12, 0, 9, 0, 0, 0, -9, 12, 9], [0, 0, 0, 1, 1, 0, -24, 1, 0, 0, 1, 0], [11, -7, 0, -5, -5, 0, 0, 5, -11, 0, 5, 7], [0, -8, 18, -8, 0, -8, 18, 0, 0, 8, -8, -8], [-1, 0, 0, 9, -9, 10, 0, 9, -1, 10, -9, 0], [0, -5, 0, 8, 0, 5, 0, 0, -30, 5, -8, 5], [0, 1, -24, 0, -1, -1, 24, -1, 0, 1, 0, 1], [13, -2, 0, -7, -7, 0, 0, 7, -13, 0, 7, 2], [0, -4, 6, 10, -10, 0, 0, -10, 0, 0, 10, -4], [0, -2, 0, -6, 0, 2, 0, 0, -6, 2, 6, 2], [-12, 5, 0, 0, 2, 5, 0, -2, 0, 5, 0, -5], [-1, 10, 0, -3, -3, 0, 0, 3, 1, 0, 3, -10], [0, -8, 12, 6, 0, -8, 12, 0, 0, 8, 6, -8], [12, 7, 0, 0, -8, 7, 0, 8, 0, 7, 0, -7], [0, 0, 0, 6, 6, 4, -30, 6, 0, -4, 6, 0], [0, -10, 12, -2, 2, 0, 0, 2, 0, 0, -2, -10], [0, -6, 0, -6, 0, -6, 0, 0, 0, 6, -6, -6], [0, -6, 0, -2, 0, 6, 0, 0, 36, 6, 2, 6], [23, 0, 0, -3, 3, 8, 0, -3, 23, 8, 3, 0], [11, 10, 0, -3, -3, 0, 0, 3, -11, 0, 3, -10], [0, 4, 12, -8, 8, 0, 0, 8, 0, 0, -8, 4], [-16, -3, 0, 0, 3, -3, 0, -3, 0, -3, 0, 3], [0, 0, 0, 2, 2, 12, 12, 2, 0, -12, 2, 0], [-26, 0, 0, 0, 15, 0, 0, -15, 0, 0, 0, 0], [0, 16, 18, -4, 4, 0, 0, 4, 0, 0, -4, 16], [0, -6, -6, -7, 0, -6, -6, 0, 0, 6, -7, -6], [0, -2, -6, 10, 0, -2, -6, 0, 0, 2, 10, -2], [7, 0, 0, 1, -1, 2, 0, 1, 7, 2, -1, 0], [0, -15, 0, 0, 0, 15, 0, 0, 14, 15, 0, 15], [0, -14, 6, -7, 7, 0, 0, 7, 0, 0, -7, -14], [0, 2, 18, 0, 10, -2, -18, 10, 0, 2, 0, 2], [0, -17, -12, 8, -8, 0, 0, -8, 0, 0, 8, -17], [-20, 3, 0, 0, 12, 3, 0, -12, 0, 3, 0, -3], [5, 0, 0, 7, -7, 3, 0, 7, 5, 3, -7, 0], [-20, -9, 0, 0, -9, -9, 0, 9, 0, -9, 0, 9], [0, -8, -24, 2, -2, 0, 0, -2, 0, 0, 2, -8], [0, -8, 12, 0, -6, 8, -12, -6, 0, -8, 0, -8], [-13, 0, 0, 6, -6, 13, 0, 6, -13, 13, -6, 0], [0, 2, -36, 0, 8, -2, 36, 8, 0, 2, 0, 2], [0, 0, 0, 9, 9, -8, -18, 9, 0, 8, 9, 0], [0, 2, 0, -7, 0, -2, 0, 0, 14, -2, 7, -2], [0, 6, 0, 6, 0, -6, 0, 0, -26, -6, -6, -6], [0, 3, 6, 0, -8, -3, -6, -8, 0, 3, 0, 3], [6, 1, 0, 0, 2, 1, 0, -2, 0, 1, 0, -1], [0, -10, 12, -2, 2, 0, 0, 2, 0, 0, -2, -10], [0, 0, 0, -7, -7, 3, -6, -7, 0, -3, -7, 0], [-23, 2, 0, -4, -4, 0, 0, 4, 23, 0, 4, -2], [-18, 2, 0, 0, 2, 2, 0, -2, 0, 2, 0, -2], [0, -11, 0, 0, 1, 11, 0, 1, 0, -11, 0, -11], [0, 0, 0, -2, -2, -2, -12, -2, 0, 2, -2, 0], [0, 7, 12, 8, -8, 0, 0, -8, 0, 0, 8, 7], [-14, -10, 0, 0, -10, -10, 0, 10, 0, -10, 0, 10], [-23, -1, 0, 4, 4, 0, 0, -4, 23, 0, -4, 1], [0, 0, 0, -2, -2, -2, 18, -2, 0, 2, -2, 0], [-13, 0, 0, -14, 14, 7, 0, -14, -13, 7, 14, 0], [0, -12, 12, -7, 0, -12, 12, 0, 0, 12, -7, -12], [0, 8, 0, -6, 0, -8, 0, 0, 0, -8, 6, -8], [0, -1, -24, 0, 15, 1, 24, 15, 0, -1, 0, -1], [0, -9, 6, 0, 8, 9, -6, 8, 0, -9, 0, -9], [0, 0, 0, 6, 0, 0, 0, 0, -20, 0, -6, 0], [0, 0, 12, 11, -11, 0, 0, -11, 0, 0, 11, 0], [0, 6, 0, 2, 0, -6, 0, 0, 36, -6, -2, -6], [-16, -2, 0, 0, -2, -2, 0, 2, 0, -2, 0, 2], [5, 0, 0, -9, 9, -18, 0, -9, 5, -18, 9, 0], [0, -1, -24, -7, 0, -1, -24, 0, 0, 1, -7, -1], [26, 12, 0, 0, 9, 12, 0, -9, 0, 12, 0, -12], [0, 0, 0, -1, -1, 9, 6, -1, 0, -9, -1, 0], [13, -4, 0, -9, -9, 0, 0, 9, -13, 0, 9, 4], [0, -17, 24, -8, 8, 0, 0, 8, 0, 0, -8, -17], [0, 10, 24, -6, 0, 10, 24, 0, 0, -10, -6, 10], [0, 11, 12, 0, -2, -11, -12, -2, 0, 11, 0, 11], [0, 0, 0, 4, 4, -6, 12, 4, 0, 6, 4, 0], [0, 4, 0, 1, 0, -4, 0, 0, -50, -4, -1, -4], [-42, 6, 0, 0, -10, 6, 0, 10, 0, 6, 0, -6], [1, 0, 0, 9, -9, -7, 0, 9, 1, -7, -9, 0], [0, 0, 0, 3, 3, -4, 54, 3, 0, 4, 3, 0], [0, 3, -24, -16, 0, 3, -24, 0, 0, -3, -16, 3], [1, 1, 0, 10, 10, 0, 0, -10, -1, 0, -10, -1], [0, 4, 24, 4, -4, 0, 0, -4, 0, 0, 4, 4], [-17, 0, 0, 6, -6, 6, 0, 6, -17, 6, -6, 0], [0, -6, 18, 2, 0, -6, 18, 0, 0, 6, 2, -6], [5, 15, 0, 3, 3, 0, 0, -3, -5, 0, -3, -15], [0, 0, 0, 13, 13, 4, -6, 13, 0, -4, 13, 0], [0, 5, -18, -13, 13, 0, 0, 13, 0, 0, -13, 5], [0, -5, 0, 13, 0, 5, 0, 0, 20, 5, -13, 5], [0, 1, 24, 0, -6, -1, -24, -6, 0, 1, 0, 1], [0, 0, 36, -5, 5, 0, 0, 5, 0, 0, -5, 0], [12, 11, 0, 0, 10, 11, 0, -10, 0, 11, 0, -11], [-1, 0, 0, 1, -1, 4, 0, 1, -1, 4, -1, 0], [0, -5, -18, -2, 0, -5, -18, 0, 0, 5, -2, -5], [19, 0, 0, 7, -7, 4, 0, 7, 19, 4, -7, 0], [0, -6, 0, 0, 0, 6, 0, 0, -32, 6, 0, 6], [0, 4, -12, 0, 3, -4, 12, 3, 0, 4, 0, 4], [-19, 0, 0, -7, 7, 1, 0, -7, -19, 1, 7, 0], [10, 3, 0, 0, 6, 3, 0, -6, 0, 3, 0, -3], [0, -6, -18, 4, -4, 0, 0, -4, 0, 0, 4, -6], [12, 4, 0, 0, -17, 4, 0, 17, 0, 4, 0, -4], [0, 0, 0, 2, 2, 5, -12, 2, 0, -5, 2, 0], [0, 0, 0, -5, -5, -2, 6, -5, 0, 2, -5, 0], [-23, -10, 0, 7, 7, 0, 0, -7, 23, 0, -7, 10], [0, 4, 30, 8, 0, 4, 30, 0, 0, -4, 8, 4], [0, -5, 0, -8, 0, 5, 0, 0, -14, 5, 8, 5], [7, 0, 0, -5, 5, 12, 0, -5, 7, 12, 5, 0], [5, 0, 0, -18, -18, 0, 0, 18, -5, 0, 18, 0], [0, -5, 0, 2, 0, 5, 0, 0, 18, 5, -2, 5], [24, 4, 0, 0, -8, 4, 0, 8, 0, 4, 0, -4], [-17, 0, 0, 5, -5, -8, 0, 5, -17, -8, -5, 0], [0, 0, 0, 12, 12, -10, -12, 12, 0, 10, 12, 0], [-43, -6, 0, -3, -3, 0, 0, 3, 43, 0, 3, 6], [-17, 10, 0, -7, -7, 0, 0, 7, 17, 0, 7, -10], [0, -2, -24, -7, 0, -2, -24, 0, 0, 2, -7, -2], [0, -13, -12, 0, -4, 13, 12, -4, 0, -13, 0, -13], [-1, -23, 0, -4, -4, 0, 0, 4, 1, 0, 4, 23], [0, 3, -12, 0, 22, -3, 12, 22, 0, 3, 0, 3], [17, 0, 0, 5, -5, -14, 0, 5, 17, -14, -5, 0], [19, -4, 0, 8, 8, 0, 0, -8, -19, 0, -8, 4], [0, -2, 12, 18, 0, -2, 12, 0, 0, 2, 18, -2], [-6, -3, 0, 0, -13, -3, 0, 13, 0, -3, 0, 3], [0, 0, 0, 8, 8, -9, 12, 8, 0, 9, 8, 0], [19, -11, 0, 4, 4, 0, 0, -4, -19, 0, -4, 11], [0, -2, 6, 16, 0, -2, 6, 0, 0, 2, 16, -2], [0, 2, 12, 0, -4, -2, -12, -4, 0, 2, 0, 2], [0, -6, 12, 0, -25, 6, -12, -25, 0, -6, 0, -6], [0, 0, 0, 8, 8, -6, -18, 8, 0, 6, 8, 0], [0, 12, 0, 3, -3, 0, 0, -3, 0, 0, 3, 12], [2, -13, 0, 0, -10, -13, 0, 10, 0, -13, 0, 13], [0, 10, -24, 12, 0, 10, -24, 0, 0, -10, 12, 10], [8, -5, 0, 0, -2, -5, 0, 2, 0, -5, 0, 5], [0, 8, 24, -4, 0, 8, 24, 0, 0, -8, -4, 8], [0, -4, 12, 0, -17, 4, -12, -17, 0, -4, 0, -4], [41, 2, 0, -4, -4, 0, 0, 4, -41, 0, 4, -2], [0, 3, 0, -13, 0, -3, 0, 0, -30, -3, 13, -3], [0, 13, 12, -10, 10, 0, 0, 10, 0, 0, -10, 13], [0, 5, 0, 8, 0, -5, 0, 0, 6, -5, -8, -5]]
